==> haskell-tls-1.3.5-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tls/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls
version: 1.3.5
id: tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
key: tls_3mTEcV7rEGs5MTZIHCbEDm
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-tls
synopsis: TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.
    .
    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.
    .
    Currently implement the SSL3.0, TLS1.0, TLS1.1 and TLS1.2 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.
    .
    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Internal Network.TLS.Extra Network.TLS.Extra.Cipher
hidden-modules: Network.TLS.Cap Network.TLS.Struct Network.TLS.Core
                Network.TLS.Context Network.TLS.Context.Internal
                Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
                Network.TLS.Crypto.DH Network.TLS.Crypto.ECDH Network.TLS.ErrT
                Network.TLS.Extension Network.TLS.Extension.EC
                Network.TLS.Handshake Network.TLS.Handshake.Common
                Network.TLS.Handshake.Certificate Network.TLS.Handshake.Key
                Network.TLS.Handshake.Client Network.TLS.Handshake.Server
                Network.TLS.Handshake.Process Network.TLS.Handshake.Signature
                Network.TLS.Handshake.State Network.TLS.Hooks Network.TLS.IO
                Network.TLS.MAC Network.TLS.Measurement Network.TLS.Packet
                Network.TLS.Parameters Network.TLS.Record Network.TLS.Record.Types
                Network.TLS.Record.Engage Network.TLS.Record.Disengage
                Network.TLS.Record.State Network.TLS.RNG Network.TLS.State
                Network.TLS.Session Network.TLS.Sending Network.TLS.Receiving
                Network.TLS.Util Network.TLS.Util.ASN1
                Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
                Network.TLS.X509
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/tls-1.3.5
hs-libraries: HStls-1.3.5-3mTEcV7rEGs5MTZIHCbEDm
depends:
    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
    x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
    x509-validation-1.6.3-2eb8745653ed8864def666b7c1efed9d
haddock-interfaces: /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html: /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-1.3.8-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tls/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls
version: 1.3.8
id: tls-1.3.8-96444b4e688bece54c4ea4192a68b9a3
key: tls_6cOQNzqL76a5Df300fVwLT
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-tls
synopsis: TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.
    .
    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.
    .
    Currently implement the SSL3.0, TLS1.0, TLS1.1 and TLS1.2 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.
    .
    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Internal Network.TLS.Extra Network.TLS.Extra.Cipher
hidden-modules: Network.TLS.Cap Network.TLS.Struct Network.TLS.Core
                Network.TLS.Context Network.TLS.Context.Internal
                Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
                Network.TLS.Crypto.DH Network.TLS.Crypto.ECDH Network.TLS.ErrT
                Network.TLS.Extension Network.TLS.Extension.EC
                Network.TLS.Handshake Network.TLS.Handshake.Common
                Network.TLS.Handshake.Certificate Network.TLS.Handshake.Key
                Network.TLS.Handshake.Client Network.TLS.Handshake.Server
                Network.TLS.Handshake.Process Network.TLS.Handshake.Signature
                Network.TLS.Handshake.State Network.TLS.Hooks Network.TLS.IO
                Network.TLS.Imports Network.TLS.MAC Network.TLS.Measurement
                Network.TLS.Packet Network.TLS.Parameters Network.TLS.Record
                Network.TLS.Record.Types Network.TLS.Record.Engage
                Network.TLS.Record.Disengage Network.TLS.Record.State
                Network.TLS.RNG Network.TLS.State Network.TLS.Session
                Network.TLS.Sending Network.TLS.Receiving Network.TLS.Util
                Network.TLS.Util.ASN1 Network.TLS.Util.Serialization
                Network.TLS.Types Network.TLS.Wire Network.TLS.X509
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/tls-1.3.8
hs-libraries: HStls-1.3.8-6cOQNzqL76a5Df300fVwLT
depends:
    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
    x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
    x509-validation-1.6.3-2eb8745653ed8864def666b7c1efed9d
haddock-interfaces: /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html: /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
